@@ -9,7 +9,7 @@ use Business::PayPal::NVP;
 use Data::Dumper;
 use Carp 'croak';
 
-our $VERSION = '0.904'; # VERSION
+our $VERSION = '0.905'; # VERSION
 
 extends 'Business::CPI::Gateway::Base';
 with 'Business::CPI::Role::Gateway::FormCheckout';
@@ -188,14 +188,15 @@ sub get_transaction_details {
     }
 
     return {
-        payment_id    => $details{INVNUM},
-        status        => lc $details{PAYMENTSTATUS},
-        amount        => $details{AMT},
-        net_amount    => $details{SETTLEAMT},
-        tax           => $details{TAXAMT},
-        exchange_rate => $details{EXCHANGERATE},
-        date          => $self->date_format->parse_datetime($details{ORDERTIME}),
-        buyer_email   => $details{EMAIL},
+        payment_id             => $details{INVNUM},
+        status                 => lc($details{PAYMENTSTATUS}),
+        amount                 => $details{AMT},
+        net_amount             => $details{SETTLEAMT},
+        tax                    => $details{TAXAMT},
+        exchange_rate          => $details{EXCHANGERATE},
+        date                   => $self->date_format->parse_datetime( $details{ORDERTIME} ),
+        buyer_email            => $details{EMAIL},
+        gateway_transaction_id => $id,
     };
 }
 
@@ -300,7 +301,7 @@ Business::CPI::Gateway::PayPal - Business::CPI's PayPal driver
 
 =head1 VERSION
 
-version 0.904
+version 0.905
 
 =head1 ATTRIBUTES
 
@@ -367,7 +368,7 @@ Renato CRON <rentocron@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by André Walker.
+This software is copyright (c) 2015 by André Walker.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
