@@ -3,7 +3,7 @@ package Business::CPI::Gateway::PayPal::IPN;
 use Moo;
 use LWP::UserAgent ();
 
-our $VERSION = '0.904'; # VERSION
+our $VERSION = '0.905'; # VERSION
 
 has is_valid => (
     is      => 'lazy',
@@ -93,7 +93,7 @@ Business::CPI::Gateway::PayPal::IPN - Instant Payment Notifications
 
 =head1 VERSION
 
-version 0.904
+version 0.905
 
 =head1 SYNOPSIS
 
@@ -137,7 +137,7 @@ It has less than one third the size (counting blank lines, but not pod). It
 uses Moo, and has a much more readable code. It has real tests, and the small
 code makes it easier to find mistakes. I removed some methods like
 C<completed>, so now you have to check: $ipn->vars->{payment_status} eq
-'Completed'. There are many more possible payment status in PayPal than what
+'Completed'. There are many more possible payment statuses in PayPal than what
 the old module expected (it implemented version 1.5, while at the time of this
 writing, PayPal's IPN is in version 3.7; so a lot has changed). So I think
 those auxiliary methods like C<completed>, C<pending>, etc, are not too useful.
@@ -174,7 +174,7 @@ The name of the user agent to post to PayPal.
 =head2 user_agent
 
 Defaults to a LWP::UserAgent object, but can be a custom object provided for
-testing purposes, or by the users preference. Could be L<Mojo::UserAgent>, for
+testing purposes, or by the user's preference. Could be L<Mojo::UserAgent>, for
 example.
 
 =head2 response
@@ -195,7 +195,7 @@ André Walker <andre@andrewalker.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by André Walker.
+This software is copyright (c) 2015 by André Walker.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
